Description Usage Arguments Value Examples
Helper Function: Cut String
1 | helper_get_substrings_table(.tab, .col_match, .min_char)
|
.tab |
A table |
.col_match |
The column with the string to be cut |
.min_char |
Number between 0 and 1 exclusively (Determines the minimum percent of the string to cut) |
A Dataframe
1 2 3 | tab <- tibble::tibble(id = 1, name = "BADISCHE ANELIN UND SODAFABRIK")
helper_get_substrings_table(tab, name, .5)
rm(tab)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.